EXPORTS
    sws_addVec
    sws_allocVec
    sws_alloc_context
    sws_alloc_set_opts
    sws_cloneVec
    sws_convVec
    sws_convertPalette8ToPacked24
    sws_convertPalette8ToPacked32
    sws_freeContext
    sws_freeFilter
    sws_freeVec
    sws_getCachedContext
    sws_getCoefficients
    sws_getColorspaceDetails
    sws_getConstVec
    sws_getContext
    sws_getDefaultFilter
    sws_getGaussianVec
    sws_getIdentityVec
    sws_get_class
    sws_init_context
    sws_isSupportedEndiannessConversion
    sws_isSupportedInput
    sws_isSupportedOutput
    sws_normalizeVec
    sws_printVec2
    sws_scale
    sws_scaleVec
    sws_setColorspaceDetails
    sws_shiftVec
    sws_subVec
    swscale_configuration
    swscale_license
    swscale_version
