EXPORTS
    av_device_capabilities
    av_device_ffversion
    av_input_audio_device_next
    av_input_video_device_next
    av_output_audio_device_next
    av_output_video_device_next
    avdevice_app_to_dev_control_message
    avdevice_capabilities_create
    avdevice_capabilities_free
    avdevice_configuration
    avdevice_dev_to_app_control_message
    avdevice_free_list_devices
    avdevice_license
    avdevice_list_devices
    avdevice_list_input_sources
    avdevice_list_output_sinks
    avdevice_register_all
    avdevice_version
